      SUBROUTINE GALP(AN,NLP,A,W,ILAT,ALP)
C 
C     * JUL 14/92 - E. CHAN (ADD REAL*8 DECLARATIONS)
C     * JULY 10/78 - J.D.HENDERSON
C     * COMPUTES LEGENDRE POLYNOMIAL SERIES FROM DATA VALUES. 
C 
C     * AN(NLP) = AMPLITUDES FOR LEGENDRE POLYNOMIAL SERIES.
C     * A(ILAT) = DATA VECTOR DEFINED ON GAUSSIAN LATITUDES.
C     * W(ILAT) = GAUSSIAN WEIGHTS FOR EACH GAUSSIAN LATITUDE.
C     * ALP(NLP,ILAT) = LEGENDRE POLYNOMIALS (NLP VALUES AT ILAT LATS). 
C 
C     * LEVEL 2,ALP 
      IMPLICIT REAL (A-H,O-Z),
     +INTEGER (I-N)
      REAL*8 ALP(NLP,ILAT),W(ILAT)
      REAL AN(NLP),A(ILAT)
C-------------------------------------------------------------------- 
      DO 310 N=1,NLP
      SUM=0.E0
      DO 210 J=1,ILAT 
  210 SUM=SUM+W(J)*A(J)*ALP(N,J)
  310 AN(N)=SUM 
C 
      RETURN
      END 
